<?php

/**
 * This is the model class for table "client_information".
 *
 * The followings are the available columns in table 'client_information':
 * @property integer $id
 * @property string $first_name
 * @property string $last_name
 * @property string $email_address
 * @property string $twilio_phone_number
 * @property string $twilio_account_sid
 * @property string $twilio_auth_token
 * @property integer $created_user
 * @property string $created_date
 * @property integer $modified_user
 * @property string $modified_date
 * @property string $twilio_account_status
 * @property integer $status
 * @property integer $type
 * @property string $password
 * @property string $sms_keywords
 * @property string $call_phrase
 * @property string $user_subscription_sms
 * @property string $user_unsubscription_sms
 * @property string $call_subscription_phrase
 * @property string $call_unsubscription_phrase
 * @property string $client_phone_number
 * @property integer $web_client_info_id
 * @property string $subscr_id
 * @property string $state
 * @property string $area_code
 * @property string $user_re_subscription_sms
 * @property string $typo_sms
 * @property string $call_msg_mp3
 * @property string $call_subscription_mp3
 * @property string $call_unsubscription_mp3
 * @property string $opt_message
 * @property string $company_name
 * @property string $address
 * @property string $city
 * @property string $zip_code
 * @property string $time_zone_id
 * @property integer $day_time_saving
 *
 * The followings are the available model relations:
 * @property ClientGroups[] $clientGroups
 * @property UserPackageAssignment[] $userPackageAssignments
 */
class client extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return client the static model class
	 */
	 public $client_name;  //='$model->first_name.$model->last_name'; //variable for concated tow columns first_name,last_name.
	 
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'client_information';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('first_name,last_name, email_address, password, company_name, address, city,state,area_code', 'required'),
			array('first_name', 'match', 'not' => true, 'pattern' => '/[^a-zA-Z ]/',
		      'message' => 'Fisrt Name must consist of letters,and spaces only' ),
			  array('last_name', 'match', 'not' => true, 'pattern' => '/[^a-zA-Z ]/',
		      'message' => 'Last Name must consist of letters,and spaces only' ),
			  array('email_address', 'email','checkMX'=>true),
			  //if it is empty then its value will be this..
			  array('sms_keywords','default','value'=>'sms keyword'),
			  
			array('created_user, modified_user, status, type, web_client_info_id, day_time_saving', 'numerical', 'integerOnly'=>true),
			array('first_name, last_name, email_address, twilio_phone_number, twilio_account_status, password, state, call_msg_mp3, call_subscription_mp3, call_unsubscription_mp3, opt_message', 'length', 'max'=>100),
			array('twilio_account_sid, twilio_auth_token, sms_keywords, subscr_id', 'length', 'max'=>250),
			//array('user_subscription_sms, user_unsubscription_sms', 'length', 'max'=>200),
			array('client_phone_number, area_code', 'length', 'max'=>50),
			//array('user_re_subscription_sms', 'length', 'max'=>170),
			array('typo_sms', 'length', 'max'=>160),
			array('company_name, address, city, zip_code', 'length', 'max'=>255),
			array('time_zone_id', 'length', 'max'=>20),
			array('modified_date,user_subscription_sms, user_unsubscription_sms,		
			 user_re_subscription_sms,call_phrase, call_subscription_phrase, call_unsubscription_phrase', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, first_name, last_name, email_address,  created_user,  client_phone_number, state, area_code, company_name, address, city, zip_code,client_name',  'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'clientGroups' => array(self::HAS_MANY, 'ClientGroups', 'client_id'),
			'userPackageAssignments' => array(self::HAS_MANY, 'UserPackageAssignment', 'user_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'first_name' => 'First Name',
			'last_name' => 'Last Name',
			'email_address' => 'Email Address',
			'state' => 'State',
			'area_code' => 'Area Code',
			'twilio_phone_number' => 'Phone Number',//'Twilio Phone Number',
			'company_name' => 'Company Name',
			'address' => 'Address',
			'city' => 'City',
			'zip_code' => 'Zip Code',
			'password' => 'Password',
			'sms_keywords' => 'Default Keywords',
			'user_subscription_sms' => 'Subscription Sms',
			'user_unsubscription_sms' => 'Unsubscription Sms',
			'user_re_subscription_sms' => 'Re-Subscription Sms',
			'call_phrase' => 'Voice Greeting',
			'call_subscription_phrase' => 'Call Subscription Message',
			'call_unsubscription_phrase' => 'Call Unsubscription Message',
			'client_phone_number' => 'Office Phone For Call',
			
			
			'created_user' => 'Created User',
			'created_date' => 'Added Date',
			'modified_user' => 'Modified User',
			'modified_date' => 'Modified Date',
			'twilio_account_sid' => 'Twilio Account Sid',
			'twilio_auth_token' => 'Twilio Auth Token',
			'twilio_account_status' => 'Twilio Account Status',
			'status' => 'Status',
			'type' => 'Type',
			'web_client_info_id' => 'Web Client Info',
			'subscr_id' => 'Subscr',
			'typo_sms' => 'Typo Sms',
			'call_msg_mp3' => 'Call Msg Mp3',
			'call_subscription_mp3' => 'Call Subscription Mp3',
			'call_unsubscription_mp3' => 'Call Unsubscription Mp3',
			'opt_message' => 'Opt Message',
			'time_zone_id' => 'Time Zone',
			'day_time_saving' => 'Day Time Saving',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.
        
		$criteria=new CDbCriteria;
		$criteria->compare('CONCAT_WS(" ",first_name,last_name)',$this->client_name,true);
		// $criteria->compare('CONCAT(first_name,last_name)',$this->first_name,true);
       	$criteria->compare('id',$this->id);
		$criteria->compare('first_name',$this->first_name,true);
		$criteria->compare('last_name',$this->last_name,true);
		$criteria->compare('email_address',$this->email_address,true);
		$criteria->compare('twilio_phone_number',$this->twilio_phone_number,true);
		$criteria->compare('twilio_account_sid',$this->twilio_account_sid,true);
		$criteria->compare('twilio_auth_token',$this->twilio_auth_token,true);
		$criteria->compare('created_user',$this->created_user);
		$criteria->compare('created_date',$this->created_date,true);
		$criteria->compare('modified_user',$this->modified_user);
		$criteria->compare('modified_date',$this->modified_date,true);
		$criteria->compare('twilio_account_status',$this->twilio_account_status,true);
		$criteria->compare('status',$this->status);
		$criteria->compare('type',$this->type);
		$criteria->compare('password',$this->password,true);
		$criteria->compare('sms_keywords',$this->sms_keywords,true);
		$criteria->compare('call_phrase',$this->call_phrase,true);
		$criteria->compare('user_subscription_sms',$this->user_subscription_sms,true);
		$criteria->compare('user_unsubscription_sms',$this->user_unsubscription_sms,true);
		$criteria->compare('call_subscription_phrase',$this->call_subscription_phrase,true);
		$criteria->compare('call_unsubscription_phrase',$this->call_unsubscription_phrase,true);
		$criteria->compare('client_phone_number',$this->client_phone_number,true);
		$criteria->compare('web_client_info_id',$this->web_client_info_id);
		$criteria->compare('subscr_id',$this->subscr_id,true);
		$criteria->compare('state',$this->state,true);
		$criteria->compare('area_code',$this->area_code,true);
		$criteria->compare('user_re_subscription_sms',$this->user_re_subscription_sms,true);
		$criteria->compare('typo_sms',$this->typo_sms,true);
		$criteria->compare('call_msg_mp3',$this->call_msg_mp3,true);
		$criteria->compare('call_subscription_mp3',$this->call_subscription_mp3,true);
		$criteria->compare('call_unsubscription_mp3',$this->call_unsubscription_mp3,true);
		$criteria->compare('opt_message',$this->opt_message,true);
		$criteria->compare('company_name',$this->company_name,true);
		$criteria->compare('address',$this->address,true);
		$criteria->compare('city',$this->city,true);
		$criteria->compare('zip_code',$this->zip_code,true);
		$criteria->compare('time_zone_id',$this->time_zone_id,true);
		$criteria->compare('day_time_saving',$this->day_time_saving);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
	/***************encryption with bcrypt in hexa method*************/
	/*
	protected function afterValidate()
    {
        $this->password = $this->encrypt($this->password);
        return parent::afterValidate();
    }
 
    public function encrypt($value)
    {
    $enc = NEW bCrypt();
        return $enc->hash($value);
    }
	*/
	/*****************encryption with md5() method********************/
	/**
* perform one-way encryption on the password before we store it in
the database
*
*/
protected function afterValidate()
{
	  parent::afterValidate();
	  $this->password = $this->encrypt($this->password);
}
public function encrypt($value)
{
	  return md5($value);
}
	
	/**** 1 for active , 0 for blocked in local system for status columns.
	***** **/


	   
       const TYPE_active=1;
	   const TYPE_block=2;
       public $status;
       public function getStatusOption()
	   {
        
		 return array(
		 self::TYPE_block=>'Blocked',
		 self::TYPE_active=>'Active',
		
		 );
    }

   public function getStatus($status)
        {
                $array  = self::getStatusOption();
                return $array[$status];
        }

	

}