<?php

/**
 * This is the model class for table "user_package_assignment".
 *
 * The followings are the available columns in table 'user_package_assignment':
 * @property integer $id
 * @property integer $user_id
 * @property integer $package_id
 * @property string $package_start_date
 * @property string $package_end_date
 * @property string $package_assign_date
 * @property integer $package_status
 * @property integer $created_user
 * @property integer $free_days
 * @property integer $is_free_days
 *
 * The followings are the available model relations:
 * @property ClientInformation $user
 * @property Packages $package
 */
class packageassignment extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return packageassignment the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'user_package_assignment';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('package_start_date, package_end_date, package_assign_date, is_free_days', 'required'),
			array('user_id, package_id, package_status, created_user, free_days, is_free_days', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, user_id, package_id, package_start_date, package_end_date, package_assign_date, package_status, created_user, free_days, is_free_days', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'user' => array(self::BELONGS_TO, 'ClientInformation', 'user_id'),
			'package' => array(self::BELONGS_TO, 'Packages', 'package_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'user_id' => 'User',
			'package_id' => 'Package',
			'package_start_date' => 'Package Start Date',
			'package_end_date' => 'Package End Date',
			'package_assign_date' => 'Package Assign Date',
			'package_status' => 'Package Status',
			'created_user' => 'Created User',
			'free_days' => 'Free Days',
			'is_free_days' => 'Is Free Days',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('package_id',$this->package_id);
		$criteria->compare('package_start_date',$this->package_start_date,true);
		$criteria->compare('package_end_date',$this->package_end_date,true);
		$criteria->compare('package_assign_date',$this->package_assign_date,true);
		$criteria->compare('package_status',$this->package_status);
		$criteria->compare('created_user',$this->created_user);
		$criteria->compare('free_days',$this->free_days);
		$criteria->compare('is_free_days',$this->is_free_days);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}