<?php

/**
 * This is the model class for table "packages".
 *
 * The followings are the available columns in table 'packages':
 * @property integer $id
 * @property string $package_title
 * @property double $package_price
 * @property string $price_description
 * @property integer $package_sms
 * @property string $package_sms_description
 * @property string $package_description
 * @property integer $recurring
 * @property string $recurring_text
 * @property integer $created_user
 * @property string $created_date
 * @property integer $modified_user
 * @property string $modified_date
 * @property integer $package_status
 * @property integer $is_free
 * @property integer $display
 * @property integer $free_package_id
 * @property integer $free_package_days
 * @property string $voice_msg
 * @property string $voice_msg_desc
 * @property string $sms_price_text
 * @property string $voice_price_text
 * @property string $email_price_text
 * @property string $mininum_order
 * @property string $no_of_contract
 * @property string $no_of_keyword
 * @property string $detail
 * @property string $two_co_id
 *
 * The followings are the available model relations:
 * @property UserPackageAssignment[] $userPackageAssignments
 */
class packages extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return packages the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'packages';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('package_title, package_price, package_sms, created_user, created_date, voice_msg, voice_msg_desc, sms_price_text, voice_price_text, email_price_text, mininum_order, no_of_contract, no_of_keyword, detail, two_co_id', 'required'),
			array('package_sms, recurring, created_user, modified_user, package_status, is_free, display, free_package_id, free_package_days', 'numerical', 'integerOnly'=>true),
			array('package_price', 'numerical'),
			array('package_title, recurring_text', 'length', 'max'=>300),
			array('price_description, package_sms_description', 'length', 'max'=>200),
			array('voice_msg, sms_price_text, voice_price_text, email_price_text, mininum_order, no_of_contract, no_of_keyword', 'length', 'max'=>50),
			array('voice_msg_desc, detail', 'length', 'max'=>255),
			array('two_co_id', 'length', 'max'=>100),
			array('package_description, modified_date', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, package_title, package_price, price_description, package_sms, package_sms_description, package_description, recurring, recurring_text, created_user, created_date, modified_user, modified_date, package_status, is_free, display, free_package_id, free_package_days, voice_msg, voice_msg_desc, sms_price_text, voice_price_text, email_price_text, mininum_order, no_of_contract, no_of_keyword, detail, two_co_id', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'userPackageAssignments' => array(self::HAS_MANY, 'UserPackageAssignment', 'package_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'package_title' => 'Name',
			'package_price' => 'Price($)',
			'price_description' => 'Description',
			'package_sms' => 'Package Sms',
			'package_sms_description' => 'Package Sms Description',
			'package_description' => 'Package Description',
			'recurring' => 'Recurring',
			'recurring_text' => 'Recurring Text',
			'created_user' => 'Created User',
			'created_date' => 'Created Date',
			'modified_user' => 'Modified User',
			'modified_date' => 'Modified Date',
			'package_status' => 'Package Status',
			'is_free' => 'Is Free',
			'display' => 'Display',
			'free_package_id' => 'Free Package',
			'free_package_days' => 'Free Package Days',
			'voice_msg' => 'Voice Msg',
			'voice_msg_desc' => 'Voice Msg Desc',
			'sms_price_text' => 'Sms Price Text',
			'voice_price_text' => 'Voice Price Text',
			'email_price_text' => 'Email Price Text',
			'mininum_order' => 'Mininum Order',
			'no_of_contract' => 'No Of Contract',
			'no_of_keyword' => 'No Of Keyword',
			'detail' => 'Detail',
			'two_co_id' => 'Two Co',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('package_title',$this->package_title,true);
		$criteria->compare('package_price',$this->package_price);
		$criteria->compare('price_description',$this->price_description,true);
		$criteria->compare('package_sms',$this->package_sms);
		$criteria->compare('package_sms_description',$this->package_sms_description,true);
		$criteria->compare('package_description',$this->package_description,true);
		$criteria->compare('recurring',$this->recurring);
		$criteria->compare('recurring_text',$this->recurring_text,true);
		$criteria->compare('created_user',$this->created_user);
		$criteria->compare('created_date',$this->created_date,true);
		$criteria->compare('modified_user',$this->modified_user);
		$criteria->compare('modified_date',$this->modified_date,true);
		$criteria->compare('package_status',$this->package_status);
		$criteria->compare('is_free',$this->is_free);
		$criteria->compare('display',$this->display);
		$criteria->compare('free_package_id',$this->free_package_id);
		$criteria->compare('free_package_days',$this->free_package_days);
		$criteria->compare('voice_msg',$this->voice_msg,true);
		$criteria->compare('voice_msg_desc',$this->voice_msg_desc,true);
		$criteria->compare('sms_price_text',$this->sms_price_text,true);
		$criteria->compare('voice_price_text',$this->voice_price_text,true);
		$criteria->compare('email_price_text',$this->email_price_text,true);
		$criteria->compare('mininum_order',$this->mininum_order,true);
		$criteria->compare('no_of_contract',$this->no_of_contract,true);
		$criteria->compare('no_of_keyword',$this->no_of_keyword,true);
		$criteria->compare('detail',$this->detail,true);
		$criteria->compare('two_co_id',$this->two_co_id,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}