<?php

/**
 * This is the model class for table "users_phone_numbers".
 *
 * The followings are the available columns in table 'users_phone_numbers':
 * @property integer $id
 * @property string $name
 * @property string $phone_number
 * @property integer $created_user
 * @property string $created_date
 * @property integer $modified_user
 * @property string $modified_date
 * @property integer $status
 * @property string $message_type
 * @property string $birthdate
 * @property string $email
 *
 * The followings are the available model relations:
 * @property PhoneNumberGroupAssignment[] $phoneNumberGroupAssignments
 */
class subscriber extends CActiveRecord
{
	
	//public $group_search;      //for searching and displaying in cgridview
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return subscriber the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'users_phone_numbers';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('phone_number, created_user, created_date, birthdate, email', 'required'),
			array('created_user, modified_user, status', 'numerical', 'integerOnly'=>true),
			array('name, phone_number', 'length', 'max'=>100),
			array('message_type', 'length', 'max'=>20),
			array('email', 'length', 'max'=>150),
			array('modified_date', 'safe'),  
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, name, phone_number, created_user, created_date, modified_user, modified_date, status, message_type, birthdate, email ', 'safe', 'on'=>'search'),//add above defined variable.
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'phoneNumberGroupAssignments' => array(self::HAS_MANY, 'Assignment', 'phone_number_id'),
			//'postCount' => array(self::STAT, 'assignment', 'phone_number_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'phone_number' => 'Phone Number',
			'created_user' => 'Created User',
			'created_date' => 'Created Date',
			'modified_user' => 'Modified User',
			'modified_date' => 'Modified Date',
			'status' => 'Status',
			'message_type' => 'Message Type',
			'birthdate' => 'Birthdate',
			'email' => 'Email',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;
		//$criteria->with = array( 'phoneNumberGroupAssignments' );   //new
		
		 
		$criteria->compare('id',$this->id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('phone_number',$this->phone_number,true);
		$criteria->compare('created_user',$this->created_user);
		$criteria->compare('created_date',$this->created_date,true);
		$criteria->compare('modified_user',$this->modified_user);
		$criteria->compare('modified_date',$this->modified_date,true);
		$criteria->compare('status',$this->status);
		$criteria->compare('message_type',$this->message_type,true);
		$criteria->compare('birthdate',$this->birthdate,true);
		$criteria->compare('email',$this->email,true);
		//$criteria->compare( 'phoneNumberGroupAssignments.group_id', $this->group_search, true );

		return new CActiveDataProvider($this, array('criteria'=>$criteria,
		/*'sort'=>array(
        'attributes'=>array(
            'group_search'=>array(
                'asc'=>'phoneNumberGroupAssignments.group_id',
                'desc'=>'phoneNumberGroupAssignments.group_id DESC',
            ),
			),
			),
			*/
			
				));
	}
}